@@ -3,7 +3,7 @@ use strict;
 our $VERSION = '0.10';
 
 use CGI qw( :standard );
-use Wiki::Toolkit::Plugin::Locator::Grid;
+use CGI::Wiki::Plugin::Locator::Grid;
 use File::Spec::Functions qw(:ALL);
 use OpenGuides::Template;
 use OpenGuides::Utils;
@@ -64,7 +64,7 @@ sub new {
         %locator_params = ( x => "easting", y => "northing" );
     }
 
-    my $locator = Wiki::Toolkit::Plugin::Locator::Grid->new( %locator_params );
+    my $locator = CGI::Wiki::Plugin::Locator::Grid->new( %locator_params );
     $wiki->register_plugin( plugin => $locator );
     $self->{locator} = $locator;
 
@@ -75,7 +75,7 @@ sub new {
 
   my $wiki = $search->wiki;
 
-An accessor; returns the underlying L<Wiki::Toolkit> object.
+An accessor; returns the underlying L<CGI::Wiki> object.
 
 =cut
 
@@ -118,19 +118,6 @@ precedence over C<return_output>.
 These two parameters exist to make testing easier; you probably don't
 want to use them in production.
 
-
-In case you're struggling to follow the code, it does the following:
-1) Processes the parameters, and bails out if it hit a problem with them
-2) If a search string was given, do a text search
-3) If distance search paramaters were given, do a distance search
-4) If no search has occured, print out the search form
-5) If an error occured, bail out
-6) If we got a single hit on a string search, redirect to it
-7) If no results were found, give an empty search results page
-8) Sort the results by either score or distance
-9) Decide which results to show, based on paging
-10) Display the appropriate page of the results
-
 =back
 
 =cut
@@ -442,7 +429,7 @@ sub _run_phrase_search {
     my %contents_res = $wiki->search_nodes( $phrase );
 
     # Rationalise the scores a little.  The scores returned by
-    # Wiki::Toolkit::Search::Plucene are simply a ranking.
+    # CGI::Wiki::Search::Plucene are simply a ranking.
     my $num_results = scalar keys %contents_res;
     foreach my $node ( keys %contents_res ) {
         $contents_res{$node} = int( $contents_res{$node} / $num_results ) + 1;
